@@ -1,6 +1,6 @@
 /* Mailnag - GNOME-Shell extension frontend
 *
-* Copyright 2013 - 2015 Patrick Ulbrich <zulu99@gmx.net>
+* Copyright 2013 - 2016 Patrick Ulbrich <zulu99@gmx.net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
@@ -21,8 +21,6 @@
 const Gio = imports.gi.Gio;
 const Gtk = imports.gi.Gtk;
 const GObject = imports.gi.GObject;
-const Mainloop = imports.mainloop;
-const Lang = imports.lang;
 const ExtensionUtils = imports.misc.extensionUtils;
 const Me = ExtensionUtils.getCurrentExtension();
 const Convenience = Me.imports.convenience;
@@ -31,8 +29,6 @@ const Gettext = imports.gettext.domain('mailnag-gnome-shell');
 const _ = Gettext.gettext;
 
 const MAX_VISIBLE_MAILS_LIMIT	= 20;
-const TIMEOUT_RESTART_HDLR		= 500; // ms
-const TIMEOUT_REENABLE			= 100; // ms
 
 
 const MailnagSettingsWidget = new GObject.Class({
@@ -46,18 +42,8 @@ const MailnagSettingsWidget = new GObject.Class({
 		this.orientation = Gtk.Orientation.VERTICAL;
 		this.margin = 12;
 		this.spacing = 6;
-		this._restart_required = false;
-		this._destroyed = false;
-		let schemaSource = Gio.SettingsSchemaSource.get_default();
-		let schemaObj = schemaSource.lookup('org.gnome.shell', true);
-		this._shell_settings = new Gio.Settings( { settings_schema: schemaObj } );
 		
 		let settings = Convenience.getSettings();
-		// Restarting the mailnag extensions whenever a setting has been changed
-		// won't work when changes happen too fast (e.g. via the spinner buttons).
-		// So just set a flag that something has been changed and defer the actual extension
-		// restart to the restart_handler which is triggered every TIMEOUT_RESTART_HDLR ms. 
-		settings.connect('changed', Lang.bind(this, function() { this._restart_required = true; }));
 		
 		let box = new Gtk.Box( { orientation: Gtk.Orientation.HORIZONTAL, spacing: 6 } );
 		box.add(new Gtk.Label( { label: _('Maximum number of visible mails:') } ));
@@ -69,46 +55,33 @@ const MailnagSettingsWidget = new GObject.Class({
 		box.add(spinbtn);
 		this.add(box);
 		
-		let checkbtn_avatars = new Gtk.CheckButton( { label: _("Show Avatars") } );
-		settings.bind('show-avatars', checkbtn_avatars, 'active', Gio.SettingsBindFlags.DEFAULT);
+		let checkbtn_remove = new Gtk.CheckButton( { label: _('Remove indicator icon if maillist is empty') } );
+		settings.bind('remove-indicator', checkbtn_remove, 'active', Gio.SettingsBindFlags.DEFAULT);
+		this.add(checkbtn_remove);
 		
+		let checkbtn_group = new Gtk.CheckButton( { label: _('Group mails by account') } );
+		settings.bind('group-by-account', checkbtn_group, 'active', Gio.SettingsBindFlags.DEFAULT);
+		this.add(checkbtn_group);
+		
+		let checkbtn_avatars = new Gtk.CheckButton( { label: _('Show avatars') } );
+		settings.bind('show-avatars', checkbtn_avatars, 'active', Gio.SettingsBindFlags.DEFAULT);
 		this.add(checkbtn_avatars);
 		
-		this.connect('destroy', Lang.bind(this, function() {
-			this._destroyed = true;
-		}));
+		let checkbtn_dates = new Gtk.CheckButton( { label: _('Show dates') } );
+		settings.bind('show-dates', checkbtn_dates, 'active', Gio.SettingsBindFlags.DEFAULT);
+		this.add(checkbtn_dates);
 		
-		Mainloop.timeout_add(TIMEOUT_RESTART_HDLR, Lang.bind(this, this._restart_handler));
-	},
-	
-	
-	_restart_handler: function() {
+		let checkbtn_mark = new Gtk.CheckButton( { label: _('Show Mark-All-As-Read button') } );
+		settings.bind('show-mark-all-as-read-button', checkbtn_mark, 'active', Gio.SettingsBindFlags.DEFAULT);
+		this.add(checkbtn_mark);
 		
-		// log ("restart handler")
+		let checkbtn_check = new Gtk.CheckButton( { label: _('Show Check-For-Mail button') } );
+		settings.bind('show-check-for-mail-button', checkbtn_check, 'active', Gio.SettingsBindFlags.DEFAULT);
+		this.add(checkbtn_check);
 		
-		if (this._restart_required) {
-			this._restart_required = false;
-			// log ("restart required");
-		
-			let enabled_extensions_orig = this._shell_settings.get_strv('enabled-extensions');
-			let enabled_extensions = [];
-		
-			for (let i = 0; i < enabled_extensions_orig.length; i++) {
-				let ext = enabled_extensions_orig[i];
-				if (ext != Me.uuid)
-					enabled_extensions.push(ext);
-			}
-		
-			this._shell_settings.set_strv('enabled-extensions', enabled_extensions);
-			// GNOME-Shell (?) seems to miss toggling of enabled extensions if it happens too fast, 
-			// so wait a bit (TIMEOUT_REENABLE) between disabling and re-enabling. 
-			Mainloop.timeout_add(TIMEOUT_REENABLE, Lang.bind(this, function() {
-				this._shell_settings.set_strv('enabled-extensions', enabled_extensions_orig);
-				return false;
-			}));
-		}
-		
-		return !this._destroyed;
+		let checkbtn_settings = new Gtk.CheckButton( { label: _('Show Settings button') } );
+		settings.bind('show-settings-button', checkbtn_settings, 'active', Gio.SettingsBindFlags.DEFAULT);
+		this.add(checkbtn_settings);
 	}
 });
 
